<?php

/* --------------------------------------------------------------------------*/
/*                                                                           */
/* QuickTime Posting WordPress Plugin								         */   
/* Written by Shawn Van Every <vanevery@walking-productions.com>             */
/*                                                                           */
/* Copyright (c) 2006-2007 Shawn Van Every <vanevery@walking-productions.com>*/
/*                                                                           */
/* This program is free software; you can redistribute it and/or             */
/* modify it under the terms of the GNU General Public License               */
/* as published by the Free Software Foundation; either version 2            */
/* of the License, or (at your option) any later version.                    */
/*                                                                           */
/* See file LICENSE for further informations on licensing terms.             */
/*                                                                           */
/* This program is distributed in the hope that it will be useful,           */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */
/* GNU General Public License for more details.                              */
/*                                                                           */
/* You should have received a copy of the GNU General Public License         */
/* along with this program; if not, write to the Free Software Foundation,   */
/* Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           */
/*                                                                           */
/* --------------------------------------------------------------------------*/


/*
Plugin Name: QuickTime Posting
Plugin URI: http://www.walking-productions.com/QuickTimePostWPP/
Description: Create QuickTime Object and Embed Tags in posts

[QUICKTIME file width height] 
OR: 
[QUICKTIME file poster_file width height]
OR: 
[QUICKTIME file width height true true] 
OR: 
[QUICKTIME file poster_file width height true true] 

In the last two versions, the first "true" is for whether or not it should autoplay and the second for whether or not the controller should be visible.  The other possibility is to say "false" for either of these arguments.

New with Version 1.3b, uses JavaScript methods to get around the annoying Alert regarding running ActiveX controls on Windows IE browsers.  Thanks to Steven Dowd (http://steven-dowd.co.uk/) for pointing out the solution and thanks to 360rage for describing it further (http://www.360rage.com/eolas-microsoft.php).

Notes:

At some point this should probably use Apple's JavaScript file for doing this: AC_QuickTime.js http://developer.apple.com/internet/ieembedprep.html

1.3.6b, fixed new problem with Firefox Embed Tag.  
fixed "theTags" vs. "ourTags" typo (thanks nate carroll)

1.3.5b, added SCALE ASPECT to the tags.

1.3.4b, added GPL Language

1.3.3b, added 'the_excerpt' filter so that on templates like hemingway the plugin will display the movie if the tag is used in the excerpt.  Also fixed a typo which may have prevented some of the arguments not to be parsed correctly when using all of the options (poster, autoplay and controller).

1.3.2b, fixed "site_url" issue for those users whose blog is in a different place than their wordpress install.

1.3.1b, closer to XHTML compliance.  The PARAM tags now have ending slashes.  Also, using JavaScript to no rely upon the wp_head function.  Checking to see if it is defined before using it.

Author: Shawn Van Every
Version: 1.3.5b
Author URI: http://www.walking-productions.com/shawn.html
*/ 

$stag = "[QUICKTIME ";
$etag = "]";

function quicktime_post($the_content)
{
    GLOBAL $stag, $etag;

    $spos = strpos($the_content, $stag);
    if ($spos !== false)
    {
        $epos = strpos($the_content, $etag, $spos);
        $spose = $spos + strlen($stag);
        $slen = $epos - $spose;
        $tagargs = substr($the_content, $spose, $slen);
        
        $the_args = explode(" ", $tagargs);
        
        if (sizeof($the_args) == 3)
        {
            list($file,$width,$height) = explode(" ", $tagargs);
            $tags = generate_tags($file,$width,$height);
            $new_content = substr($the_content,0,$spos);
            $new_content .= $tags;
            $new_content .= substr($the_content,($epos+1));
        }
        else if (sizeof($the_args) == 4)
        {
            list($file,$poster,$width,$height) = explode(" ", $tagargs);
            $tags = generate_tags($file,$width,$height,$poster);
            $new_content = substr($the_content,0,$spos);
            $new_content .= $tags;
            $new_content .= substr($the_content,($epos+1));
        }
        else if (sizeof($the_args) == 5)
        {
            list($file,$width,$height,$autoplay,$controller) = explode(" ",$tagargs);
            $poster = "";
            $tags = generate_tags($file,$width,$height,$poster,$autoplay,$controller);
            $new_content = substr($the_content,0,$spos);
            $new_content .= $tags;
            $new_content .= substr($the_content,($epos+1));
        }
        else if (sizeof($the_args) == 6)
        {
            list($file,$poster,$width,$height,$autoplay,$controller) = explode(" ",$tagargs);
            $tags = generate_tags($file,$width,$height,$poster,$autoplay,$controller);
            $new_content = substr($the_content,0,$spos);
            $new_content .= $tags;
            $new_content .= substr($the_content,($epos+1));
        }
                
        if ($epos+1 < strlen($the_content))
        {
            $new_content = quicktime_post($new_content);
        }
        return $new_content;
    }
    else
    {
        return $the_content;
    }
}

function generate_tags($file, $width, $height, $poster = "", $autoplay = "false", $controller = "")
{
    $script_tags = "\n<script type=\"text/javascript\">\n";
    $script_tags .= "<!--\n";
    
    $script_tags .= "var ourTags='';\n";

    $tag_line = "<OBJECT CLASSID=\"clsid:02BF25D5-8C17-4B23-BC80-D3488ABDDC6B\" WIDTH=\"" . $width . "\" HEIGHT=\"" . $height . "\" CODEBASE=\"http://www.apple.com/qtactivex/qtplugin.cab\">";
    $tags .= $tag_line . "\n";
    $script_tags .= "ourTags+='" . $tag_line . "';\n";
    
    if ($poster == "")
    {
    	if ($controller == "")
    	{
            $controller = "true";
        }

        $tag_line = "<PARAM name=\"SRC\" VALUE=\"" . $file . "\" />";
        $tags .= $tag_line . "\n";
        $script_tags .= "ourTags+='" . $tag_line . "';\n";

        $tag_line = "<PARAM name=\"CONTROLLER\" VALUE=\"" . $controller . "\" />";    
        $tags .= $tag_line . "\n";
        $script_tags .= "ourTags+='" . $tag_line . "';\n";
    }
    else
    {
        if ($controller == "") 
        {
            $controller = "false";
        }
        
        $tag_line = "<PARAM name=\"HREF\" VALUE=\"" . $file . "\" />";
        $tags .= $tag_line . "\n";
        $script_tags .= "ourTags+='" . $tag_line . "';\n";

        $tag_line = "<PARAM name=\"SRC\" VALUE=\"" . $poster . "\" />";
        $tags .= $tag_line . "\n";
        $script_tags .= "ourTags+='" . $tag_line . "';\n";

        $tag_line = "<PARAM name=\"TARGET\" VALUE=\"myself\" />";
        $tags .= $tag_line . "\n";
        $script_tags .= "ourTags+='" . $tag_line . "';\n";

        $tag_line = "<PARAM name=\"CONTROLLER\" VALUE=\"" . $controller . "\" />";
        $tags .= $tag_line . "\n";
        $script_tags .= "ourTags+='" . $tag_line . "';\n";
    }
    
    $tag_line = "<PARAM name=\"AUTOPLAY\" VALUE=\"" . $autoplay . "\" />";
    $tags .= $tag_line . "\n";
    $script_tags .= "ourTags+='" . $tag_line . "';\n";
    
    $tag_line = "<PARAM name=\"SCALE\" VALUE=\"ASPECT\" />";
    $tags .= $tag_line . "\n";
    $script_tags .= "ourTags+='" . $tag_line . "';\n";
    
    $tag_line = "<EMBED ";
    $tags .= $tag_line . "\n";
    $script_tags .= "ourTags+='" . $tag_line . "';\n";
    
    if ($poster == "") 
    {
        $tag_line = "SRC=\"" . $file . "\" CONTROLLER=\"" . $controller . "\"";
        $tags .= $tag_line . "\n";
        $script_tags .= "ourTags+='" . $tag_line . "';\n";
    }
    else
    {
        $tag_line = "SRC=\"" . $poster . "\" HREF=\"" . $file . "\" TARGET=\"myself\" CONTROLLER=\"" . $controller . "\"";    
        $tags .= $tag_line . "\n";
        $script_tags .= "ourTags+='" . $tag_line . "';\n";
    }
    
    $tag_line = " type=\"video/quicktime\" WIDTH=\"" . $width . "\" HEIGHT=\"" . $height . "\" AUTOPLAY=\"" . $autoplay . "\" SCALE=\"ASPECT\" PLUGINSPAGE=\"http://www.apple.com/quicktime/download/\"></EMBED>";
    $tags .= $tag_line . "\n";
    $script_tags .= "ourTags+='" . $tag_line . "';\n";

    $tag_line = "</OBJECT>";    
    $tags .= $tag_line . "\n";
    $script_tags .= "ourTags+='" . $tag_line . "';\n";

    $script_tags .= "if (typeof writeTags == \"undefined\") { "; // This isn't tested at all
    $script_tags .= "document.write(ourTags);";
    $script_tags .= "} else {";
    $script_tags .= "writeTags(ourTags);\n";
    $script_tags .= "}";
    $script_tags .= "//-->\n</script>\n";
    $script_tags .= "<noscript>\n";
    $script_tags .= $tags . "\n";
    $script_tags .= "</noscript>\n";
        
    return $script_tags;
}

function quicktime_post_js()
{
    $linktojs = get_bloginfo('wpurl') . "/wp-content/plugins/quicktimepost.js";
    echo "\n<script language=\"javascript\" type=\"text/javascript\" src=\"" . $linktojs . "\"></script>\n";
}

add_filter('the_content', 'quicktime_post');
add_filter('the_excerpt','quicktime_post');
add_action('wp_head','quicktime_post_js');
?>
